@@ -45,14 +45,13 @@ class EWAHOracleSQLOperator(EWAHSQLBaseOperator):
                     return dict(zip(columnNames, args))
                 return createRow
 
-            connection = BaseHook.get_connection(self.source_conn_id)
             oracle_conn = cx_Oracle.connect(
-                connection.login,
-                connection.password,
+                self.source_conn.login,
+                self.source_conn.password,
                 '{0}:{1}/{2}'.format(
-                    connection.host,
-                    connection.port,
-                    connection.schema,
+                    self.source_conn.host,
+                    self.source_conn.port,
+                    self.source_conn.schema,
                 ),
                 encoding='UTF-8'
             )
