@@ -7,7 +7,7 @@ class EWAHPostgresOperator(EWAHSQLBaseOperator):
     _SQL_BASE = \
         'SELECT\n{columns}\nFROM "{schema}"."{table}"\nWHERE {where_clause}'
     _SQL_BASE_SELECT = \
-        'WITH raw AS ({select_sql}) SELECT * FROM raw WHERE {{0}}'
+        'WITH raw_data AS ({select_sql}) SELECT * FROM raw_data WHERE {{0}}'
     _SQL_COLUMN_QUOTE = '"'
     _SQL_MINMAX_CHUNKS = '''
         WITH base AS ({base})
@@ -25,7 +25,7 @@ class EWAHPostgresOperator(EWAHSQLBaseOperator):
         super().__init__(*args, **kwargs)
 
     def _get_data_from_sql(self, sql, params=None, return_dict=True):
-        hook = EWAHDWHookPostgres(self.source_conn_id)
+        hook = EWAHDWHookPostgres(self.source_conn)
         self.log.info('Executing:\n{0}\n\nWith params:\n{1}'.format(
             sql,
             str(params),
